@@ -1,6 +1,7 @@
 from psycopg2 import sql
 import psycopg2
 import json
+import traceback
 
 class Postgres_Handler:
     #Key for table_name string
@@ -193,35 +194,39 @@ class Postgres_Handler:
         
     #Method to update a SQL row
     def update_record(self, **kwargs):
-        values_dict = {}
-        id_key = 'Id'
-        clause_section = ''
-        
-         #checks for the table name in args
-        if self.table_name_key not in kwargs:
-            print("Error: table_name required as argument")
-            assert("Error: table_name required as argument")
-        table_name = kwargs[self.table_name_key]
-        
-        #Begining of the SQL query
-        query_string= f"UPDATE {table_name} SET"
-        
-        for key, value in kwargs.items():
-            if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
+        try:
+            values_dict = {}
+            id_key = 'Id'
+            clause_section = ''
             
-            clause_section = f' "{key}" = %({key})s AND'
-            values_dict[key] = value
-        
-        query_string += clause_section[:-4]
+                #checks for the table name in args
+            if self.table_name_key not in kwargs:
+                print("Error: table_name required as argument")
+                assert("Error: table_name required as argument")
+            table_name = kwargs[self.table_name_key]
+            
+            #Begining of the SQL query
+            query_string= f"UPDATE {table_name} SET"
+            
+            for key, value in kwargs.items():
+                if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
+                
+                clause_section = f' "{key}" = %({key})s AND'
+                values_dict[key] = value
+            
+            query_string += clause_section[:-4]
 
-        if id_key not in kwargs: assert("Error: ID of record required for an update!")
-        
-        query_string += f' WHERE "ID"=%(Id)s'
-        values_dict[id_key] = kwargs[id_key]
-        
-        results = self.__run_query(query_string)
-        
-        return self.__format_results(results)
+            if id_key not in kwargs: assert("Error: ID of record required for an update!")
+            
+            query_string += f' WHERE "ID"=%(Id)s'
+            values_dict[id_key] = kwargs[id_key]
+            
+            results = self.__run_query(query_string, values_dict)
+            
+            return self.__format_results(results)
+        except Exception as ex:
+            print(ex)
+            print(traceback.format_exc(ex))
     
     #Delete command, will use policy or agent number to delete
     #todo - This may requrie removing items from S3 not sure yet how that will work
